netapp_ontap.resources.local_cifs_user API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.local_cifs_user`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

The CIFS server can use local users for CIFS authentication. The local users can also be used for authorization when determining both share and file/directory access rights to data residing on the storage virtual machine (SVM). You can use this API to display local user information and to control local user configurations.

## Retrieving local user information

You can use the local user GET endpoint to retrieve all of the local user configurations for data SVMs.

## Examples

### Retrieving all of the fields for local user configurations for all SVMs

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LocalCifsUser.get_collection(fields="**")))

Try it out

    [
        LocalCifsUser(
            {
                "full_name": "",
                "name": "CIFS_SERVER1\\Administrator",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-500",
                "description": "Built-in administrator account",
                "membership": [{"sid": "S-1-5-32-544", "name": "BUILTIN\\Administrators"}],
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "local user1",
                "name": "CIFS_SERVER1\\user1",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-1001",
                "description": "This is CIFS local user",
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "local user2",
                "name": "CIFS_SERVER1\\user2",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-1002",
                "description": "This is CIFS local user",
                "membership": [
                    {
                        "sid": "S-1-5-21-256008430-3394229847-3930036330-1001",
                        "name": "CIFS_SERVER1\\grp1",
                    },
                    {
                        "sid": "S-1-5-21-256008430-3394229847-3930036330-1002",
                        "name": "CIFS_SERVER1\\grp2",
                    },
                ],
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "",
                "name": "CIFS_SERVER2\\Administrator",
                "account_disabled": False,
                "sid": "S-1-5-21-1625922807-3304708894-3529444428-500",
                "description": "Built-in administrator account",
                "membership": [{"sid": "S-1-5-32-544", "name": "BUILTIN\\Administrators"}],
                "svm": {"name": "vs2", "uuid": "3f479a01-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "local user1",
                "name": "CIFS_SERVER2\\user1",
                "account_disabled": False,
                "sid": "S-1-5-21-1625922807-3304708894-3529444428-1001",
                "description": "This is CIFS local user",
                "svm": {"name": "vs2", "uuid": "3f479a01-2971-11eb-88e1-0050568eefd4"},
            }
        ),
    ]

### Retrieving the local user configuration of a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                LocalCifsUser.get_collection(
                    fields="**", **{"svm.uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
                )
            )
        )

Try it out

    [
        LocalCifsUser(
            {
                "full_name": "",
                "name": "CIFS_SERVER1\\Administrator",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-500",
                "description": "Built-in administrator account",
                "membership": [{"sid": "S-1-5-32-544", "name": "BUILTIN\\Administrators"}],
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "local user1",
                "name": "CIFS_SERVER1\\user1",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-1001",
                "description": "This is CIFS local user",
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
        LocalCifsUser(
            {
                "full_name": "local user2",
                "name": "CIFS_SERVER1\\user2",
                "account_disabled": False,
                "sid": "S-1-5-21-256008430-3394229847-3930036330-1002",
                "description": "This is CIFS local user",
                "membership": [
                    {
                        "sid": "S-1-5-21-256008430-3394229847-3930036330-1001",
                        "name": "CIFS_SERVER1\\grp1",
                    },
                    {
                        "sid": "S-1-5-21-256008430-3394229847-3930036330-1002",
                        "name": "CIFS_SERVER1\\grp2",
                    },
                ],
                "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
            }
        ),
    ]

### Retrieving a local user configuration of a specific SVM and user

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LocalCifsUser(
            sid="S-1-5-21-1625922807-3304708894-3529444428-1001",
            **{"svm.uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
        )
        resource.get()
        print(resource)

Try it out

    LocalCifsUser(
        {
            "full_name": "local user1",
            "name": "CIFS_SERVER1\\user1",
            "account_disabled": False,
            "sid": "S-1-5-21-256008430-3394229847-3930036330-1001",
            "description": "This is CIFS local user",
            "svm": {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"},
        }
    )

## Creating a local user configuration

The local user POST endpoint creates a local user configuration for the specified SVM.

## Examples

### Creating a local user configuration with all fields specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LocalCifsUser()
        resource.account_disabled = False
        resource.description = "This is local user."
        resource.full_name = "user name"
        resource.name = "SMB_SERVER01\user"
        resource.password = "netapp1N"
        resource.svm = {"name": "vs1", "uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
        resource.post(hydrate=True)
        print(resource)

### Creating a local user configuration with only mandatory fields specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LocalCifsUser()
        resource.name = "user1"
        resource.password = "netapp1N"
        resource.svm = {"uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
        resource.post(hydrate=True)
        print(resource)

## Updating a local user configuration

The local user PATCH endpoint updates the local user configuration for the specified user and SVM.

### Updating a local user name and password

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LocalCifsUser(
            sid="S-1-5-21-1625922807-3304708894-3529444428-1001",
            **{"svm.uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
        )
        resource.name = "new_user1"
        resource.password = "netapp1Net"
        resource.patch()

## Deleting a local user configuration

The local user DELETE endpoint deletes the specified local user for the specified SVM. The following example shows a DELETE operation:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LocalCifsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LocalCifsUser(
            sid="S-1-5-21-1625922807-3304708894-3529444428-1001",
            **{"svm.uuid": "25b363a6-2971-11eb-88e1-0050568eefd4"}
        )
        resource.delete()

## Classes

`class LocalCifsUser (*args, **kwargs)`

  Allows interaction with LocalCifsUser objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all LocalCifsUser resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('LocalCifsUser')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a local user configuration for the specified SVM.

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user delete`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent LocalCifsUser resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves local users for all of the SVMs. Local groups to which this user belongs to are also displayed.

    ### Advanced properties

    - `membership`

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user show`
    - `vserver cifs users-and-groups local-user show-membership`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves local users for all of the SVMs. Local groups to which this user belongs to are also displayed.

    ### Advanced properties

    - `membership`

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user show`
    - `vserver cifs users-and-groups local-user show-membership`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('LocalCifsUser')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates local user information for the specified user and SVM. The PATCH endpoint is also used to rename a user and to set the password for the user.

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user modify`
    - `vserver cifs users-and-groups local-user rename`
    - `vserver cifs users-and-groups local-user set-password`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('LocalCifsUser')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[LocalCifsUser], NetAppResponse]`

    Creates the local user configuration for an SVM.

    ### Important notes

    - The user name can contain up to 20 characters.
    - The user name cannot be terminated by a period.
    - The user name does not support any of the following characters: " / ? [ ] , : | < > + = ; ? * @ or ASCII characters in the range 1-31.
    - The password must be at least six characters in length and must not contain the user account name.
    - The password must contain characters from three of the following four categories:
    - English uppercase characters (A through Z)
    - English lowercase characters (a through z)
    - Base 10 digits (0 through 9)
    - Special characters: ~ ! @ # 0 ^ & * _ - + = ` ? | ( ) [ ] : ; " ' < > , . ? /

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the local user.
    - `name` - Name of the local user.
    - `password` - Password for the local user.

    ### Default property values

    If not specified in POST, the following default property value is assigned: * `account_disabled` - false

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user create`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a local user configuration for the specified SVM.

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user delete`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves local user information for the specified user and SVM.

    ### Advanced properties

    - `membership`

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user show`
    - `vserver cifs users-and-groups local-user show-membership`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates local user information for the specified user and SVM. The PATCH endpoint is also used to rename a user and to set the password for the user.

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user modify`
    - `vserver cifs users-and-groups local-user rename`
    - `vserver cifs users-and-groups local-user set-password`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates the local user configuration for an SVM.

    ### Important notes

    - The user name can contain up to 20 characters.
    - The user name cannot be terminated by a period.
    - The user name does not support any of the following characters: " / ? [ ] , : | < > + = ; ? * @ or ASCII characters in the range 1-31.
    - The password must be at least six characters in length and must not contain the user account name.
    - The password must contain characters from three of the following four categories:
    - English uppercase characters (A through Z)
    - English lowercase characters (a through z)
    - Base 10 digits (0 through 9)
    - Special characters: ~ ! @ # 0 ^ & * _ - + = ` ? | ( ) [ ] : ; " ' < > , . ? /

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the local user.
    - `name` - Name of the local user.
    - `password` - Password for the local user.

    ### Default property values

    If not specified in POST, the following default property value is assigned: * `account_disabled` - false

    ### Related ONTAP commands

    - `vserver cifs users-and-groups local-user create`

    ### Learn more

    - `DOC /protocols/cifs/local-users`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class LocalCifsUserSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LocalCifsUser object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `account_disabled: bool GET POST PATCH`

    Indicates whether the user account is enabled or disabled.

  `description: str GET POST PATCH`

    Description for the local user.

    Example: This is local user.

  `full_name: str GET POST PATCH`

    User's full name.

    Example: user name

  `links: SelfLink GET`

    The links field of the local_cifs_user.

  `membership: List[LocalUserMembership] GET`

    Specifies local groups of which this local user is a member.

  `name: str GET POST PATCH`

    Local user name. The maximum supported length of an user name is 20 characters.

    Example: SMB_SERVER01\user

  `password: str POST PATCH`

    Password for the local user.

  `sid: str GET`

    The security ID of the local user which uniquely identifies the user. The user SID is automatically generated in POST and it is retrieved using the GET method.

    Example: S-1-5-21-256008430-3394229847-3930036330-1001

  `svm: Svm GET POST PATCH`

    The svm field of the local_cifs_user.